@@ -6,6 +6,10 @@
 
 #include "pg_migrator.h"
 
+#ifdef EDB_NATIVE_LANG
+#include <fcntl.h>
+#endif
+
 #include <sys/stat.h>
 #ifdef WIN32
 #include <windows.h>
