@@ -309,6 +309,8 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 			  Cluster whichCluster)
 {
 	PGconn	   *conn = connectToServer(ctx, db_name, whichCluster);
+	bool		is_edb_as = (whichCluster == CLUSTER_OLD) ?
+					ctx->old.is_edb_as : ctx->new.is_edb_as;
 	PGresult   *res;
 	RelInfo    *relinfos;
 	int			ntups;
@@ -328,9 +330,9 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 				"SELECT DISTINCT c.oid, n.nspname, c.relname, "
 				"	c.relfilenode, c.reltoastrelid, "
 				"	t.spclocation,n.nspname "
-				"FROM (pg_catalog.pg_class c JOIN "
+				"FROM pg_catalog.pg_class c JOIN "
 				"		pg_catalog.pg_namespace n "
-				"	ON c.relnamespace = n.oid) "
+				"	ON c.relnamespace = n.oid "
 				"   LEFT OUTER JOIN pg_catalog.pg_tablespace t "
 				"	ON c.reltablespace = t.oid "
 				"WHERE relnamespace NOT IN "
@@ -344,7 +346,7 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 				STRINGIFY(FirstNormalObjectId) " "
 				"	AND "
 				"	(relkind = 'r' OR relkind = 't' OR "
-				"	 relkind = 'i'%s)"
+				"	 relkind = 'i'%s)%s"
 				"GROUP BY  c.oid, n.nspname, c.relname, c.relfilenode,"
 				"			c.reltoastrelid, t.spclocation, "
 				"			n.nspname "
@@ -352,8 +354,39 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 				/* see the comment at the top of v8_3_adjust_sequences() */
 				(GET_MAJOR_VERSION(ctx->old.pg_version) <= 803 &&
 				 GET_MAJOR_VERSION(ctx->new.pg_version) >= 804) ?
-					"" : " OR relkind = 'S'");
-
+					"" : " OR relkind = 'S'",
+				/*
+				 *	EDB AS installs pgagent by default via initdb.
+				 *	We have to ignore it, and not migrate any old
+				 *	table contents.
+				 */
+				(is_edb_as && strcmp(db_name, "edb") == 0) ?
+				" 	AND "
+				"	n.nspname != 'pgagent' AND "
+				/* skip pgagent TOAST tables */
+				"	c.oid NOT IN "
+				"	( "
+				"		SELECT c2.reltoastrelid "
+                "		FROM pg_catalog.pg_class c2 JOIN "
+                "				pg_catalog.pg_namespace n2 "
+                "			ON c2.relnamespace = n2.oid "
+				"		WHERE n2.nspname = 'pgagent' AND "
+				"			  c2.reltoastrelid != 0 "
+				"	) AND "
+				/* skip pgagent TOAST table indexes */
+				"	c.oid NOT IN "
+				"	( "
+				"		SELECT c3.reltoastidxid "
+                "		FROM pg_catalog.pg_class c2 JOIN "
+                "				pg_catalog.pg_namespace n2 "
+                "			ON c2.relnamespace = n2.oid JOIN "
+                "				pg_catalog.pg_class c3 "
+				"			ON c2.reltoastrelid = c3.oid "
+				"		WHERE n2.nspname = 'pgagent' AND "
+				"			  c2.reltoastrelid != 0 AND "
+				"			  c3.reltoastidxid != 0 "
+				"	) " : "");
+		
 	res = executeQueryOrDie(ctx, conn, query);
 
 	ntups = PQntuples(res);
