@@ -67,6 +67,10 @@ main(int argc, char **argv)
 	get_tablespace_paths(&ctx);
 	get_loadable_libraries(&ctx);
 
+	check_for_composite_types(&ctx, CLUSTER_OLD);
+	check_for_array_types(&ctx, CLUSTER_OLD);
+	check_for_enum_types(&ctx, CLUSTER_OLD);
+
 	/* Check for various failure cases */
 	v8_3_check_for_isn_and_int8_passing_mismatch(&ctx, CLUSTER_OLD);
 	if (GET_MAJOR_VERSION(ctx.old.pg_version) <= 803 &&
@@ -74,9 +78,6 @@ main(int argc, char **argv)
 	{
 		v8_3_check_for_name_data_type_usage(&ctx, CLUSTER_OLD);
 		v8_3_check_for_tsquery_usage(&ctx, CLUSTER_OLD);
-		v8_3_check_for_composite_types(&ctx, CLUSTER_OLD);
-		v8_3_check_for_array_types(&ctx, CLUSTER_OLD);
-		v8_3_check_for_enum_types(&ctx, CLUSTER_OLD);
 		if (ctx.check)
 		{
 			v8_3_rebuild_tsvector_tables(&ctx, true, CLUSTER_OLD);
