@@ -2,7 +2,7 @@
  *	pg_migrator.h
  */
 
-#define	PG_MIGRATOR_VERSION	"8.4.2"
+#define	PG_MIGRATOR_VERSION	"8.4.3"
 
 #include "postgres.h"
 
@@ -389,13 +389,7 @@ void		v8_3_check_for_name_data_type_usage(migratorContext *ctx,
 							Cluster whichCluster);
 void		v8_3_check_for_tsquery_usage(migratorContext *ctx,
 							Cluster whichCluster);
-void		v8_3_check_for_composite_types(migratorContext *ctx,
-							Cluster whichCluster);
-void		v8_3_check_for_array_types(migratorContext *ctx,
-							Cluster whichCluster);
-void		v8_3_check_for_enum_types(migratorContext *ctx,
-							Cluster whichCluster);
-void		v8_3_check_for_isn_and_int8_passing_mismatch(migratorContext *ctx,
+void		 v8_3_check_for_isn_and_int8_passing_mismatch(migratorContext *ctx,
 							Cluster whichCluster);
 void		v8_3_rebuild_tsvector_tables(migratorContext *ctx,
 							bool check_mode, Cluster whichCluster);
@@ -405,4 +399,9 @@ void		v8_3_invalidate_bpchar_pattern_ops_indexes(migratorContext *ctx,
 							bool check_mode, Cluster whichCluster);
 char 		*v8_3_create_sequence_script(migratorContext *ctx,
 							Cluster whichCluster);
-
+void		check_for_composite_types(migratorContext *ctx,
+							Cluster whichCluster);
+void		check_for_array_types(migratorContext *ctx,
+							Cluster whichCluster);
+void		check_for_enum_types(migratorContext *ctx,
+							Cluster whichCluster);
